@@ -68,6 +68,8 @@ private:
   Score * currentScore();
   Score * findScore(QString & clubName, QString & courseName);
   void flushReadOnlyItems();
+  void markHomeClub();
+  void sortScoreList();
                                
   void showNote(QString msg);
   void getStat(QTextEdit *);
