@@ -326,6 +326,8 @@ void ScoreDialog::init(Course *course, Score *score)
             table->setItem(ROW_SCORE_2, i-9, scoreItem);
         }
     }
+    // This - for some unknown reason - does not work ...
+    table->setInputMethodHints(Qt::ImhDigitsOnly);
 
     // Set focus to 1st cell
     table->setCurrentCell(ROW_SCORE, 0);
